# SessionDescribe

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | 
**applied_snapshots** | [**list[AppliedSnapshot]**](AppliedSnapshot.md) |  | 
**commands** | [**list[SessionCommand]**](SessionCommand.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


